#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IS_SIMD_LOGICAL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IS_SIMD_LOGICAL_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/scalar/is_simd_logical.hpp>

#endif
